@@ -1,16 +1,25 @@
+test_hiredis_connection <- function(...) {
+  skip_if_no_redis()
+  hiredis(...)
+}
+
 ## Helpers that will be used by both redux and rrlite (possibly after
 ## translation).
-skip_if_no_redis <- function() {
-  if (redis_available()) {
+skip_if_no_redis <- function(...) {
+  testthat::skip_on_cran()
+  if (identical(Sys.getenv("REDUX_TEST_USE_REDIS"), "true") &&
+      redis_available(...)) {
     return()
   }
   testthat::skip("Redis is not available")
 }
 
 skip_if_not_isolated_redis <- function() {
-  ## TODO: set this so that some tests can be skipped unless I flag
-  ## that we're allowed to do destructive things.
-  return()
+  if (identical(Sys.getenv("ISOLATED_REDIS"), "true") ||
+      identical(Sys.getenv("TRAVIS"), "true")) {
+    return()
+  }
+  testthat::skip("Redis is not isolated (set envvar ISOLATED_REDIS to 'true')")
 }
 
 skip_if_no_scan <- function(r) {
