@@ -17,6 +17,13 @@ test_that("Filter", {
                length(tmp))
   expect_equal(length(filter_redis_commands(tmp, as.character(mv))),
                length(tmp))
+
+  con <- test_hiredis_connection()
+  v <- redis_version(con)
+  ans1 <- filter_redis_commands(tmp, TRUE, con$command)
+  ans2 <- filter_redis_commands(tmp, v)
+  expect_equal(sort(names(ans1)),
+               sort(names(ans2)))
 })
 
 test_that("filter -- sanity checking", {
